==> libreoffice-5.4.0.3.tar.xz: libreoffice-5.4.0.3/chart2/source/tools/WrappedDirectStateProperty.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "WrappedDirectStateProperty.hxx"
#include "macros.hxx"

using namespace ::com::sun::star;

using ::com::sun::star::uno::Reference;

namespace chart
{

WrappedDirectStateProperty::WrappedDirectStateProperty(
    const OUString& rOuterName, const OUString& rInnerName ) :
        WrappedProperty( rOuterName, rInnerName )
{}

WrappedDirectStateProperty::~WrappedDirectStateProperty()
{}

beans::PropertyState WrappedDirectStateProperty::getPropertyState(
    const Reference< beans::XPropertyState >& /* xInnerPropertyState */ ) const
{
    return beans::PropertyState_DIRECT_VALUE;
}

} //  namespace chart

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.2.7.orig.tar.xz: libreoffice-6.2.7/chart2/source/tools/WrappedDirectStateProperty.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <WrappedDirectStateProperty.hxx>

using namespace ::com::sun::star;

using ::com::sun::star::uno::Reference;

namespace chart
{

WrappedDirectStateProperty::WrappedDirectStateProperty(
    const OUString& rOuterName, const OUString& rInnerName ) :
        WrappedProperty( rOuterName, rInnerName )
{}

WrappedDirectStateProperty::~WrappedDirectStateProperty()
{}

beans::PropertyState WrappedDirectStateProperty::getPropertyState(
    const Reference< beans::XPropertyState >& /* xInnerPropertyState */ ) const
{
    return beans::PropertyState_DIRECT_VALUE;
}

} //  namespace chart

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
